package TestNothing;
# This is loaded by some of the debugged test scripts
1;
